@@ -5,7 +5,7 @@ use strict;
 
 #use AutoLoader qw(AUTOLOAD);
 
-use Encode::Encoding;
+use Encode::Encoding 0.1;
 use Carp;
 
 use TeX::Encode::charmap;
@@ -13,7 +13,7 @@ use TeX::Encode::BibTeX;
 
 our @ISA = qw(Encode::Encoding);
 
-our $VERSION = '1.3';
+our $VERSION = '2.001'; # VERSION
 
 __PACKAGE__->Define(qw(LaTeX latex));
 
@@ -332,8 +332,18 @@ L<Encode::Encoding>, L<Pod::LaTeX>, L<Encode>
 
 =head1 AUTHOR
 
+=over 4
+
+=item *
+
 Timothy D Brody, E<lt>tdb01r@ecs.soton.ac.ukE<gt>
 
+=item *
+
+Ahmad Fatoum C<< <athreef@cpan.org> >>, L<http://a3f.at>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 Copyright (C) 2005-2007 by Timothy D Brody
